@@ -2,10 +2,13 @@ package cmdconfig
 
 import (
 	"fmt"
+	"os"
 
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 	"github.com/spf13/viper"
+	"github.com/turbot/steampipe/pkg/constants"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
@@ -27,14 +30,38 @@ func OnCmd(cmd *cobra.Command) *CmdBuilder {
 		defer utils.LogTime(fmt.Sprintf("cmd.%s.PreRun end", cmd.CommandPath()))
 		// bind flags
 		for flagName, flag := range cfg.bindings {
+			if flag == nil {
+				// we can panic here since this is bootstrap code and not execution path specific
+				panic(fmt.Sprintf("flag for %s cannot be nil", flagName))
+			}
+			//nolint:golint,errcheck // nil check above
 			viper.GetViper().BindPFlag(flagName, flag)
 		}
+
+		// now that we have done all the flag bindings, run the global pre run
+		// this will load up and populate the global config, init the logger and
+		// also run the daily task runner
+		preRunHook(cmd, args)
+
 		// run the original PreRun
 		if originalPreRun != nil {
 			originalPreRun(cmd, args)
 		}
 	}
 
+	originalPostRun := cfg.cmd.PostRun
+	cfg.cmd.PostRun = func(cmd *cobra.Command, args []string) {
+		utils.LogTime(fmt.Sprintf("cmd.%s.PostRun start", cmd.CommandPath()))
+		defer utils.LogTime(fmt.Sprintf("cmd.%s.PostRun end", cmd.CommandPath()))
+		// run the original PostRun
+		if originalPostRun != nil {
+			originalPostRun(cmd, args)
+		}
+
+		// run the post run
+		postRunHook(cmd, args)
+	}
+
 	// wrap over the original Run function
 	originalRun := cfg.cmd.Run
 	cfg.cmd.Run = func(cmd *cobra.Command, args []string) {
@@ -81,6 +108,27 @@ func (c *CmdBuilder) AddBoolFlag(name string, defaultValue bool, desc string, op
 	return c
 }
 
+// AddCloudFlags is helper function to add the cloud flags to a command
+func (c *CmdBuilder) AddCloudFlags() *CmdBuilder {
+	return c.
+		AddStringFlag(constants.ArgCloudHost, constants.DefaultCloudHost, "Turbot Pipes host").
+		AddStringFlag(constants.ArgCloudToken, "", "Turbot Pipes authentication token")
+}
+
+// AddWorkspaceDatabaseFlag is helper function to add the workspace-databse flag to a command
+func (c *CmdBuilder) AddWorkspaceDatabaseFlag() *CmdBuilder {
+	return c.
+		AddStringFlag(constants.ArgWorkspaceDatabase, constants.DefaultWorkspaceDatabase, "Turbot Pipes workspace database")
+}
+
+// AddModLocationFlag is helper function to add the mod-location flag to a command
+func (c *CmdBuilder) AddModLocationFlag() *CmdBuilder {
+	cwd, err := os.Getwd()
+	error_helpers.FailOnError(err)
+	return c.
+		AddStringFlag(constants.ArgModLocation, cwd, "Path to the workspace working directory")
+}
+
 // AddStringSliceFlag is a helper function to add a flag that accepts an array of strings
 func (c *CmdBuilder) AddStringSliceFlag(name string, defaultValue []string, desc string, opts ...flagOpt) *CmdBuilder {
 	c.cmd.Flags().StringSlice(name, defaultValue, desc)
