@@ -6,10 +6,10 @@ import (
 	"io"
 	"strings"
 
-	"github.com/karrick/gows"
-	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/control/controlexecute"
+	"github.com/turbot/steampipe/pkg/display"
+	"github.com/turbot/steampipe/pkg/utils"
 )
 
 const MaxColumns = 200
@@ -20,8 +20,8 @@ type TextFormatter struct {
 
 func (tf TextFormatter) Format(_ context.Context, tree *controlexecute.ExecutionTree) (io.Reader, error) {
 	renderer := NewTableRenderer(tree)
-	widthConstraint := NewRangeConstraint(renderer.MinimumWidth(), MaxColumns)
-	renderedText := renderer.Render(tf.getMaxCols(widthConstraint))
+	widthConstraint := utils.NewRangeConstraint(renderer.MinimumWidth(), MaxColumns)
+	renderedText := renderer.Render(widthConstraint.Constrain(display.GetMaxCols()))
 	res := strings.NewReader(fmt.Sprintf("\n%s\n", renderedText))
 	return res, nil
 }
@@ -37,12 +37,3 @@ func (tf TextFormatter) Name() string {
 func (tf TextFormatter) Alias() string {
 	return constants.OutputFormatBrief
 }
-
-func (tf TextFormatter) getMaxCols(constraint RangeConstraint) int {
-	colsAvailable, _, _ := gows.GetWinSize()
-	// check if STEAMPIPE_CHECK_DISPLAY_WIDTH env variable is set
-	if viper.IsSet(constants.ArgCheckDisplayWidth) {
-		colsAvailable = viper.GetInt(constants.ArgCheckDisplayWidth)
-	}
-	return constraint.Constrain(colsAvailable)
-}
