@@ -2,6 +2,7 @@ package modconfig
 
 import (
 	"fmt"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"log"
 	"path"
 	"reflect"
@@ -10,7 +11,6 @@ import (
 	"github.com/hashicorp/hcl/v2"
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
 	"github.com/turbot/steampipe/pkg/utils"
 	"golang.org/x/exp/maps"
@@ -120,7 +120,7 @@ func NewPos(sourcePos hcl.Pos) Pos {
 func NewConnection(block *hcl.Block) *Connection {
 	return &Connection{
 		Name:         block.Labels[0],
-		DeclRange:    NewRange(hclhelpers.BlockRange(block)),
+		DeclRange:    NewRange(hcl_helpers.BlockRange(block)),
 		ImportSchema: ImportSchemaEnabled,
 		// default to plugin
 		Type: ConnectionTypePlugin,
@@ -157,7 +157,7 @@ func (c *Connection) SetOptions(opts options.Options, block *hcl.Block) hcl.Diag
 		diags = append(diags, &hcl.Diagnostic{
 			Severity: hcl.DiagError,
 			Summary:  fmt.Sprintf("invalid nested option type %s - only 'connection' options blocks are supported for Connections", reflect.TypeOf(o).Name()),
-			Subject:  hclhelpers.BlockRangePointer(block),
+			Subject:  hcl_helpers.BlockRangePointer(block),
 		})
 	}
 	return diags
