@@ -7,12 +7,12 @@ import (
 	"github.com/turbot/steampipe/pkg/constants"
 )
 
-// General
 type General struct {
 	UpdateCheck *string `hcl:"update_check"`
 	MaxParallel *int    `hcl:"max_parallel"`
 	Telemetry   *string `hcl:"telemetry"`
 	LogLevel    *string `hcl:"log_level"`
+	MemoryMaxMb *int    `hcl:"memory_max_mb"`
 }
 
 // ConfigMap creates a config map that can be merged with viper
@@ -31,11 +31,14 @@ func (g *General) ConfigMap() map[string]interface{} {
 	if g.LogLevel != nil {
 		res[constants.ArgLogLevel] = g.LogLevel
 	}
+	if g.MemoryMaxMb != nil {
+		res[constants.ArgMemoryMaxMb] = g.MemoryMaxMb
+	}
 
 	return res
 }
 
-// Merge :: merge other options over the the top of this options object
+// Merge merges other options over the top of this options object
 // i.e. if a property is set in otherOptions, it takes precedence
 func (g *General) Merge(otherOptions Options) {
 	switch o := otherOptions.(type) {
@@ -56,5 +59,28 @@ func (g *General) String() string {
 	} else {
 		str = append(str, fmt.Sprintf("  UpdateCheck: %s", *g.UpdateCheck))
 	}
+
+	if g.MaxParallel == nil {
+		str = append(str, "  MaxParallel: nil")
+	} else {
+		str = append(str, fmt.Sprintf("  MaxParallel: %d", *g.MaxParallel))
+	}
+
+	if g.Telemetry == nil {
+		str = append(str, "  Telemetry: nil")
+	} else {
+		str = append(str, fmt.Sprintf("  Telemetry: %s", *g.Telemetry))
+	}
+	if g.LogLevel == nil {
+		str = append(str, "  LogLevel: nil")
+	} else {
+		str = append(str, fmt.Sprintf("  LogLevel: %s", *g.LogLevel))
+	}
+
+	if g.MemoryMaxMb == nil {
+		str = append(str, "  MemoryMaxMb: nil")
+	} else {
+		str = append(str, fmt.Sprintf("  MemoryMaxMb: %d", *g.MemoryMaxMb))
+	}
 	return strings.Join(str, "\n")
 }
