@@ -2,16 +2,14 @@ package parse
 
 import (
 	"fmt"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"log"
 	"strings"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
-	"github.com/hashicorp/hcl/v2/hclwrite"
-	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/zclconf/go-cty/cty"
 	"golang.org/x/exp/maps"
@@ -77,7 +75,7 @@ func DecodeConnection(block *hcl.Block) (*modconfig.Connection, hcl.Diagnostics)
 				diags = append(diags, &hcl.Diagnostic{
 					Severity: hcl.DiagWarning,
 					Summary:  fmt.Sprintf("%s in %s have been deprecated and will be removed in subsequent versions of steampipe", constants.Bold("'connection' options"), constants.Bold("'connection' blocks")),
-					Subject:  hclhelpers.BlockRangePointer(connectionBlock),
+					Subject:  hcl_helpers.BlockRangePointer(connectionBlock),
 				})
 			}
 
@@ -86,7 +84,7 @@ func DecodeConnection(block *hcl.Block) (*modconfig.Connection, hcl.Diagnostics)
 			diags = append(diags, &hcl.Diagnostic{
 				Severity: hcl.DiagError,
 				Summary:  fmt.Sprintf("connections do not support '%s' blocks", block.Type),
-				Subject:  hclhelpers.BlockRangePointer(connectionBlock),
+				Subject:  hcl_helpers.BlockRangePointer(connectionBlock),
 			})
 		}
 	}
@@ -101,14 +99,14 @@ func DecodeConnection(block *hcl.Block) (*modconfig.Connection, hcl.Diagnostics)
 				diags = append(diags, &hcl.Diagnostic{
 					Severity: hcl.DiagError,
 					Summary:  fmt.Sprintf("connections do not support '%s' blocks", b.Type),
-					Subject:  hclhelpers.HclSyntaxBlockRangePointer(b),
+					Subject:  hcl_helpers.HclSyntaxBlockRangePointer(b),
 				})
 			}
 		}
 	}
 
 	// convert the remaining config to a hcl string to pass to the plugin
-	config, moreDiags := pluginConnectionConfigToHclString(rest, connectionContent)
+	config, moreDiags := hcl_helpers.HclBodyToHclString(rest, connectionContent)
 	if moreDiags.HasErrors() {
 		diags = append(diags, moreDiags...)
 	} else {
@@ -159,70 +157,10 @@ func getPluginInstanceFromDependency(dependencies []*modconfig.ResourceDependenc
 	if len(dependencies[0].Traversals) != 1 {
 		return "", false
 	}
-	traversalString := hclhelpers.TraversalAsString(dependencies[0].Traversals[0])
+	traversalString := hcl_helpers.TraversalAsString(dependencies[0].Traversals[0])
 	split := strings.Split(traversalString, ".")
 	if len(split) != 2 || split[0] != "plugin" {
 		return "", false
 	}
 	return split[1], true
 }
-
-// build a hcl string with all attributes in the connection config which are NOT specified in the coneciton block schema
-// this is passed to the plugin who will validate and parse it
-func pluginConnectionConfigToHclString(body hcl.Body, connectionContent *hcl.BodyContent) (string, hcl.Diagnostics) {
-	var diags hcl.Diagnostics
-	f := hclwrite.NewEmptyFile()
-	rootBody := f.Body()
-
-	// this is a bit messy
-	// we want to extract the attributes which are NOT in the connection block schema
-	// the body passed in here is the 'rest' result returned from a partial decode, meaning all attributes and blocks
-	// in the schema are marked as 'hidden'
-
-	// body.JustAttributes() returns all attributes which are not hidden (i.e. all attributes NOT in the schema)
-	//
-	// however when calling JustAttributes for a hcl body, it will fail if there are any blocks
-	// therefore this code will fail for hcl connection config which has any child blocks (e.g  connection options)
-	//
-	// it does work however for a json body as this implementation treats blocks as attributes,
-	// so the options block is treated as a hidden attribute and excluded
-	// we therefore need to treaty hcl and json body separately
-
-	// store map of attribute expressions
-	attrExpressionMap := make(map[string]hcl.Expression)
-
-	if hclBody, ok := body.(*hclsyntax.Body); ok {
-		// if we can cast to a hcl body, read all the attributes and manually exclude those which are in the schema
-		for name, attr := range hclBody.Attributes {
-			// exclude attributes we have already handled
-			if _, ok := connectionContent.Attributes[name]; !ok {
-				attrExpressionMap[name] = attr.Expr
-			}
-		}
-	} else {
-		// so the body was not hcl - we assume it is json
-		// try to call JustAttributes
-		attrs, diags := body.JustAttributes()
-		if diags.HasErrors() {
-			return "", diags
-		}
-		// the attributes returned will only be the ones not in the schema, i.e. we do not need to filter them ourselves
-		for name, attr := range attrs {
-			attrExpressionMap[name] = attr.Expr
-		}
-	}
-
-	// build ordered list attributes
-	var sortedKeys = helpers.SortedMapKeys(attrExpressionMap)
-	for _, name := range sortedKeys {
-		expr := attrExpressionMap[name]
-		val, moreDiags := expr.Value(nil)
-		if moreDiags.HasErrors() {
-			diags = append(diags, moreDiags...)
-		} else {
-			rootBody.SetAttributeValue(name, val)
-		}
-	}
-
-	return string(f.Bytes()), diags
-}
