@@ -4,8 +4,8 @@ import (
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/go-kit/helpers"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"reflect"
 	"strings"
@@ -92,12 +92,8 @@ func getResourceSchema(resource modconfig.HclResource, nestedStructs []any) *hcl
 	// TODO handle duplicates and required/optional
 	// now merge the schemas
 	for _, s := range schemas {
-		for _, b := range s.Blocks {
-			res.Blocks = append(res.Blocks, b)
-		}
-		for _, a := range s.Attributes {
-			res.Attributes = append(res.Attributes, a)
-		}
+		res.Blocks = append(res.Blocks, s.Blocks...)
+		res.Attributes = append(res.Attributes, s.Attributes...)
 	}
 
 	// special cases for manually parsed attributes and blocks
@@ -213,7 +209,7 @@ func resolveReferences(body hcl.Body, resourceMapsProvider modconfig.ResourceMap
 			if _, ok := v.(modconfig.HclResource); ok {
 				if hclVal, ok := attributes[hclAttribute]; ok {
 					if scopeTraversal, ok := hclVal.Expr.(*hclsyntax.ScopeTraversalExpr); ok {
-						path := hclhelpers.TraversalAsString(scopeTraversal.Traversal)
+						path := hcl_helpers.TraversalAsString(scopeTraversal.Traversal)
 						if parsedName, err := modconfig.ParseResourceName(path); err == nil {
 							if r, ok := resourceMapsProvider.GetResource(parsedName); ok {
 								f := rv.FieldByName(field.Name)
