@@ -2,10 +2,9 @@ package parse
 
 import (
 	"fmt"
-
 	"github.com/hashicorp/hcl/v2"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/go-kit/helpers"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
@@ -70,7 +69,7 @@ func checkForDuplicateChildren(names []string, block *hcl.Block) hcl.Diagnostics
 			diags = append(diags, &hcl.Diagnostic{
 				Severity: hcl.DiagError,
 				Summary:  fmt.Sprintf("'%s.%s' has duplicate child name '%s'", block.Type, block.Labels[0], n),
-				Subject:  hclhelpers.BlockRangePointer(block)})
+				Subject:  hcl_helpers.BlockRangePointer(block)})
 		}
 		nameMap[n] = nameCount + 1
 	}
